/**
 * @file button.h
 * @author Rmi Heredero (remi@heredero.ch)
 * @version 0.1
 * @date 2023-06-06
 * 
 */
#ifndef BUTTON_H
#define BUTTON_H

#include <stdint.h>
#include <stdbool.h>
#include "../../xf/xf.h"

#define PB_POLL_TIME 20

typedef enum {ST_PBINIT,  ST_PBRELEASED, ST_PBPRESSED} BUTTON_STATES;
typedef enum {evPBInit=100, evPBPoll} BUTTON_EVENTS;

typedef void (*fButtonCallback)(void*);
typedef struct {
    fButtonCallback fCallBack;
    void* param;
} buttonCallBack;

typedef struct {
    uint8_t id;
    BUTTON_STATES state;
    buttonCallBack press;
    buttonCallBack release;
} BUTTON;


void BUTTON_init(BUTTON* me, uint8_t id);
void BUTTON_initHW(BUTTON* me);
bool BUTTON_isPressed(BUTTON* me);
void BUTTON_startBehaviour(BUTTON* me);
bool BUTTON_processEvent(Event* ev);
void BUTTON_setEventFunctions(BUTTON* me, buttonCallBack fPress, buttonCallBack release);
buttonCallBack BUTTON_defineCallBack(fButtonCallback f, void* param);

#endif	/* BUTTON_H */